declare class EventCenter {
    eventMGR: Map<string, Set<(payload?: any) => void>>;
    emitCache: Map<string, Set<string>>;
    constructor();
    on(eventName: string, callback: (payload?: any) => void, shouldTrigger?: false): void;
    off(eventName: string, callback: (payload?: any) => void): void;
    emit(eventName: string, payload?: any): void;
}
interface IFileWriter {
    fileSizeQuota: number;
    maxDaysToKeepFile: number;
}
declare type MediaSrouce = MediaStream | HTMLAudioElement;
declare type startWriteVideoFileParams = {
    videoStream?: MediaStream;
    shareScreen?: boolean;
    recordMicrophone?: boolean;
    createNewFile?: boolean;
    folderNameKey: string;
};
export declare const CHANNEL_NAME: string;
export declare class FileWriter extends EventCenter {
    handle: Worker;
    props: IFileWriter;
    audioContext: AudioContext;
    hasPermission: boolean;
    audioDestinationNode: MediaStreamAudioDestinationNode;
    defaultArgs: {
        videoFolderPath: '/User/Zoom/Localtest';
        videoFileName: 'video.webm';
    };
    realTimeLogFileHandle: FileSystemFileHandle;
    latestVideoDirHandle: FileSystemDirectoryHandle;
    videoDirHandle: FileSystemDirectoryHandle;
    logDirHandle: FileSystemDirectoryHandle;
    rootDir: FileSystemDirectoryHandle;
    isWritingNormalLog: boolean;
    constructor(props: IFileWriter);
    init(): void;
    initAudioContext(): void;
    setupListener(): void;
    addAudioSource(source: MediaSrouce): void;
    selectLogDirectory(forceReSelect?: boolean): Promise<void>;
    createLogAndVideoDirHandle(rootDir: FileSystemDirectoryHandle): Promise<void>;
    startWriteVideoFile({ videoStream, shareScreen, recordMicrophone, folderNameKey }: startWriteVideoFileParams): Promise<void>;
    pauseWriteVideoFile(): void;
    resumeWriteVideoFile(): void;
    stopWriteVideoFile(): void;
    startWriteNormalLogFile({ filenamePrefix, filenameExtension, moveToDestDirStrategy }: {
        filenamePrefix: string;
        filenameExtension: string;
        moveToDestDirStrategy?: 'none' | 'after-each-finished';
    }): void;
    setMessagePort(port: MessagePort): void;
    createMessagePort(): MessagePort;
    writeLog(text: string): void;
    saveLogFile(moveToDestDirStrategy?: 'after-all-finished'): void;
    getOPFSFilesInfoByDate(startDate?: number, endDate?: number): void;
    getOPFSFileInfoByName(filename: string): Promise<File>;
    moveOPFSFileByDate({ startDate, endDate, includeUnfinishedFiles }: {
        startDate: number;
        endDate: number;
        includeUnfinishedFiles?: boolean;
    }): Promise<void>;
    startWriteRealTimeLogFile({ fileName, fileExtension, inteval2update, }: {
        fileName?: string;
        fileExtension?: string;
        inteval2update?: number;
        maybeReuseExistingFile: boolean;
    }): Promise<void>;
    stopWriteRealTimeLog(): void;
    clearOPFSFiles(): void;
    destroy(): void;
}
declare type IFileLogger = {
    channel: BroadcastChannel;
    fileWriter: FileWriter;
    channelName: string;
    log: (str: string) => void;
    getWriter: () => Promise<FileWriter>;
    createUI: () => void;
};
declare const FileLogger: IFileLogger;
export declare const FileLoggerForWorker: (global: any) => any;
export declare function workerBuilder(worker: () => void, deps: Array<(global: any) => any>): Worker;
export default FileLogger;
